#
# spec file for package apache-parent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           apache-parent
Version:        31
Release:        2.3
Summary:        Parent POM file for Apache projects
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/apache/maven-apache-parent
Source0:        https://repo1.maven.org/maven2/org/apache/apache/%{version}/apache-%{version}-source-release.zip
Source1:        https://repo1.maven.org/maven2/org/apache/apache/%{version}/apache-%{version}-source-release.zip.asc
Source2:        https://downloads.apache.org/maven/KEYS#/%{name}.keyring
BuildRequires:  javapackages-local
BuildRequires:  unzip
BuildArch:      noarch

%description
This package contains the parent pom file for apache projects.

%prep
%setup -q -n apache-%{version}

%pom_remove_plugin :maven-site-plugin
%pom_remove_plugin :maven-remote-resources-plugin
%pom_remove_plugin :maven-enforcer-plugin

%install
# pom
install -dm 755 %{buildroot}%{_mavenpomdir}
install -pm 644 pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom

%files -f .mfiles
%license LICENSE
%doc NOTICE

%changelog
* Tue Apr 30 2024 Fridrich Strba <fstrba@suse.com>
- Simplify the spec: remove old macros and fetch updated keyring
* Fri Jan 19 2024 Fridrich Strba <fstrba@suse.com>
- update to 31:
  * New Feature
    + MPOM-440: Add maven-checkstyle-plugin to pluginManagement
  * Improvement
    + MPOM-399: Set minimalMavenBuildVersion to 3.6.3 - the minimum
    used by plugins
    + MPOM-378: Using an SPDX identifier as the license name is
    recommended by Maven
    + MPOM-289: Use properties to define the versions of plugins
  * Bug
    + MPOM-386: update documentation for previous changes
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 28:
  * [MPOM-345] - Respect property assembly.tarLongFileMode
  * [MPOM-347] - Allow custom Release Distribution Repository
  * [MPOM-323] Upgrade fluido skin to 1.11.0 by @slawekjaranowski in #86
  * [MPOM-322] Add ASF Data Privacy by @slawekjaranowski in #85
  * [MPOM-333] Drop outdated maven-docck-plugin from pluginManagement
  * [MPOM-334] Upgrade fluido skin to 1.11.1 by @slawekjaranowski in #90
  * [MPOM-305] Set minimum enforced Maven version to 3.2.5
  * [MPOM-288] - Update m-plugin-p to 3.6.4 by @kwin in #63
  * [MPOM-287] - Disable m2e warning for m-remote-resource-p:process
  * [MPOM-209]. Corrected Jira URL. by @ofarganc in #3
  * [MPOM-251] update minimum version to 3.1.1 by @elharo in #20
  * [MNGSITE-393] assume Maven 3 by @elharo in #21
  * [MPOM-256] Remove outdated clirr-maven-plugin by @slachiewicz in #27
  * [MPOM-260] simplify m-javadoc-p configuration by @hboutemy in #34
  * [MPOM-243] configure release profile with dedicated parameter by @kwin
  * [MPOM-244] upload SHA-512 only for source-release to staging repo by
  * [MPOM-263] enforce minimum Java build version 8 by @kwin in #46
* Fri Apr 23 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- SPEC file: Fixed URL tag
* Tue Apr  6 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Check upstream source signature
* Tue Oct 23 2018 Fridrich Strba <fstrba@suse.com>
- Initial packaging of apache-parent
